function format_axes_export(aspect_ratio, file_name)
% FORMAT_AXES_EXPORT formats FIGURE AXES plotted by MATLAB
% and export the figure to emf and pdf files
% Argument 'aspect_ratio' is a 1x2 array
% Argument 'file_name' is a string
% to indicate width and height of the plotted figure.
% Created on 06/17/2024, J.Z.CIBR
% Updated on 07/02/2024, J.Z.CIBR
% Updated on 09/16/2024, J.Z.CIBR, added rescale
% Updated on 11/01/2024, J.Z.CIBR, added space to margins

% example
% load count.dat;
% figure; plot(1:size(count),count,'-','linewidth',2); hold on;
% set(gca,'xtick',1:5:n);
% legend('LN-1','LN-2','LN-3','Location','NorthWest');
% legend('boxoff');
% xlabel('Time (ms)');
% ylabel('Cell count');
% format_axes_export([1,1],'panel_a');

    title({' ',get(gca,'title').String});
    ylabel({' ',get(gca,'ylabel').String});
    
    if nargin == 0 || isempty(aspect_ratio)
        aspect_ratio = [1,1];
        file_name = 'exported_plot';
    elseif nargin == 1
        file_name = 'exported_plot';
    end

    
    clc;
    rescale = 2;
    axes_handle = gca;
    box off;

    % adjust legend token size
    leg = findobj(gcf,'Tag','legend');
    if ~isempty(leg)
        leg.ItemTokenSize = size(leg.ItemTokenSize)*6.8;
    end
    
    % adjust tick size, depending on if current axis is squared
    box_aspect = get(axes_handle,'PlotBoxAspectRatio');
    if box_aspect(1) == box_aspect(2)
        tick_size = min(0.026/aspect_ratio(1),0.026/aspect_ratio(2));
    else
        tick_size = min(0.02/aspect_ratio(1),0.02/aspect_ratio(2));
    end
    
    % figure size adjusted by aspect ratio
    W = 190*rescale; H = 182*rescale;
    fig_width = W * aspect_ratio(1);
    fig_height = H * aspect_ratio(2);
    
    % adjust figure and axis appearance
    set(axes_handle,'Color','None');
    set(gcf,'unit','pixels','position',[100,100,fig_width,fig_height]);
    set(axes_handle,'Position',[0.36,0.26,0.52,0.42]); % [0.36,0.26,0.52,0.65]
    set(axes_handle,'LineWidth',0.45*rescale,'FontSize',6*rescale,'TickLength',[tick_size,tick_size],'tickdir','out');
    set(axes_handle,'FontName', 'Arial');
    set(findall(axes_handle,'Type','Text'),'FontWeight', 'Normal');

    % adjust ticklabels away from axes
    axes_handle.XRuler.TickLabelGapOffset = -1;
    axes_handle.YRuler.TickLabelGapOffset = 0;

    set(gca,'Layer','top');

    exportgraphics(gcf,strcat('~exported_',file_name,'.emf'),'ContentType','vector','BackgroundColor','none');
    exportgraphics(gcf,strcat('~exported_',file_name,'.pdf'),'ContentType','vector','BackgroundColor','none');
    clc;
    disp(strcat('------figure saved in EMF and PDF!------'));    


    % Initialize click counter
    clickCounter = 0;
    setappdata(gcf, 'clickCounter', clickCounter);
    % Set up the figure to detect clicks
    set(gcf, 'WindowButtonDownFcn', {@countClicks, file_name});

end


% Callback function to count clicks
function countClicks(src, ~, file_name)
    % Get the current click count
    clickCount = getappdata(src, 'clickCounter');
    
    % Increment the click count
    clickCount = clickCount + 1;
    
    % Update the click count in the figure's application data
    setappdata(src, 'clickCounter', clickCount);
    
    if ~mod(clickCount,2)
        exportgraphics(gcf,strcat('~exported_',file_name,'.emf'),'ContentType','vector','BackgroundColor','none');
        exportgraphics(gcf,strcat('~exported_',file_name,'.pdf'),'ContentType','vector','BackgroundColor','none');
        clc;
        disp(strcat('------figure saved in EMF and PDF!------'));
    else
        clc;
        disp(strcat('------waiting for next mouse click------'));
    end
end

